<?php
namespace Ep\Cache\Adapter;

use Ep\Cache\Exception\OptionRequiredException;
use Interop\Container\ContainerInterface;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\NotFoundExceptionInterface;
use Symfony\Component\Cache\Adapter\PhpArrayAdapter;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu PhpArray CacheAdaptera.
 *
 * @package Ep\Cache\Adapter
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class PhpArrayFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return PhpArrayAdapter
     *
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function __invoke( ContainerInterface $container, $requestedName, array $options = null ): PhpArrayAdapter
    {
        $options = $options ?? [];

        if (empty($options['file'])) {
            throw new OptionRequiredException("Polje 'file' je obavezno.");
        }

        $fallback = isset($options['fallback']) && !empty($options['fallback'])
            ? $container->get($options['fallback'])
            : null;

        return new PhpArrayAdapter($options['file'], $fallback);
    }
}
