<?php
namespace Ep\Cache\Adapter;

use Ep\Cache\Exception\OptionRequiredException;
use Interop\Container\ContainerInterface;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\NotFoundExceptionInterface;
use Symfony\Component\Cache\Adapter\ProxyAdapter;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Proxy CacheAdaptera.
 *
 * @package Ep\Cache\Adapter
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class ProxyFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return ProxyAdapter
     *
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null): ProxyAdapter
    {
        $options = $options ?? [];

        $namespace = $options['namespace'] ?? '';
        $defaultLifetime = intval($options['default_lifetime'] ?? 0);

        if (empty($options['cache'])) {
            throw new OptionRequiredException("Polje 'cache' je obavezno.");
        }

        $cache = $container->get($options['cache']);

        return new ProxyAdapter($cache, $namespace, $defaultLifetime);
    }
}
